#! /bin/bash
# ----------------------------------------------------------------------------
# /var/install/config.d/wsdd-update.sh - paramater update script
#
# Creation   : 2020-02-24 Peter Baeumer
# Last update: $Id: wsdd-update.sh 3238 2024-03-21 05:32:45Z root $
#
# Copyright (c) 2020 Peter Baeumer, <eisfair(at)baeumer(dot)duckdns(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/wsdd-update-trace$$.log
#set -x

# Include configlib for using printvar
. /var/install/include/configlib

# Include eislib
. /var/install/include/eislib

# Set package name
packageName=wsdd

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_WSDD='no'
WSDD_ADDRESS_FAMILY='IPv4only'
WSDD_VERBOSE='none'
WSDD_LOG_INTERVAL='monthly'
WSDD_LOG_COUNT='7'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} '2020-02-24' 'Peter Baeumer' "2020 - $(date +"%Y Peter Bäumer eisfair(at)baeumer(dot)duckdns(dot)org")"
    # ------------------------------------------------------------------------

    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar 'START_WSDD'   'Use: yes or no'
    printvar 'WSDD_ADDRESS_FAMILY' 'Use: IPv4only|IPv6only|both'
    #-------------------------------------------------------------------------
    printgroup "LOG configuration"
    # ------------------------------------------------------------------------
    printvar 'WSDD_VERBOSE' 'Use: none, info or debug'
    printvar 'WSDD_LOG_INTERVAL' 'daily|weekly|monthly'
    printvar 'WSDD_LOG_COUNT' 'Anzah der Logdateien'
    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{
    printgpl --check ${packageName} '2020-02-24' 'Peter Baeumer' "2020 - $(date +"%Y Peter Bäumer eisfair(at)baeumer(dot)duckdns(dot)org")" >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG
# Variable            OPT_VARIABLE     VARIABLE_N                        VALUE
START_WSDD            -                -                                 YESNO
WSDD_ADDRESS_FAMILY   START_WSDD       -                   WSDD_ADDRESS_FAMILY
WSDD_VERBOSE          START_WSDD       -                          WSDD_VERBOSE
WSDD_LOG_INTERVAL     START_WSDD       -                          LOG_INTERVAL
WSDD_LOG_COUNT        START_WSDD       -                               NUMERIC
EOFG

# Set rights for check.d file
chmod 0600 /etc/check.d/${packageName}
chown root /etc/check.d/${packageName}

printgpl --check_exp ${packageName} '2020-03-10' 'Peter Baeumer' "2020 - $(date +"%Y Peter Bäumer eisfair(at)baeumer(dot)duckdns(dot)org")" >/etc/check.d/${packageName}.exp

cat >> /etc/check.d/${packageName}.exp <<EOFG
WSDD_ADDRESS_FAMILY = 'IPv4only|IPv6only|both'
                    : 'IPv4only, IPv6only, both'
WSDD_VERBOSE = 'none|info|debug'
             : 'none, info, debug'
EOFG

# Set rights for check.exp file
chmod 0600 /etc/check.d/${packageName}.exp
chown root /etc/check.d/${packageName}.exp

#    printgpl --check_ext ${packageName} '2020-02-24' 'Peter Baeumer' "2020 - $(date +"%Y Peter Bäumer eisfair(at)baeumer(dot)duckdns(dot)org")" >/etc/check.d/${packageName}.ext
#    cat >> /etc/check.d/${packageName}.ext <<EOFG
#
#
#EOFG

    # Set rights for check.ext file
#    chmod 0600 /etc/check.d/${packageName}.ext
#    chown root /etc/check.d/${packageName}.ext
}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
makeConfigFile /etc/default.d/${packageName}

# Update from old version
renameOldVariables

# Write new config file
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
makeCheckFile

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
