#! /bin/bash
# ----------------------------------------------------------------------------
# /var/install/config.d/wsdd - WSDD configuration
#
# Creation   : 2020-02-24 Peter Baeumer
# Last update: $Id: wsdd.sh 3238 2024-03-21 05:32:45Z root $
#
# Copyright (c) 2020 Peter Baeumer, <eisfair(at)baeumer(dot)duckdns(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/wsdd-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Config Dateien
# ----------------------------------------------------------------------------
# set package name
packageName=wsdd
wsddLog=/var/log/log.wsdd

# ----------------------------------------------------------------------------
# source fies
# ----------------------------------------------------------------------------

# Include eislib
. /var/install/include/eislib

# Include config
. /etc/config.d/wsdd
. /etc/config.d/samba

# ----------------------------------------------------------------------------
# functions
# ----------------------------------------------------------------------------
# create start stop scripts
createStartStopScripts ()
{
    ### symbolic links
    rm -f /etc/rc2.d/[KS]??$packageName
}

# create logrotate file
createLogrotateFile ()
{
    LOGROTATEFILE="/etc/logrotate.d/${packageName}"
    (
        echo "#-----------------------------------------------------------------------------"
        echo "# ${LOGROTATEFILE} file generated by $0 "
        echo "# ${LOGROTATEFILE}"
        echo "# Do not change this file"
        echo "# Creation date: `date` "
        echo "#-----------------------------------------------------------------------------"
        echo ""
        echo "${wsddLog} {"
        echo "  $WSDD_LOG_INTERVAL"
        echo "  missingok"
        echo "  rotate $WSDD_LOG_COUNT"
        echo "  compress"
        echo "  delaycompress"
        echo "  notifempty"
        echo "  postrotate"
        echo "  /bin/systemctl restart wsdd.service"
        echo "  endscript"
        echo "}"
    ) > ${LOGROTATEFILE}
}

createWsddEnvFile ()
{
    case $WSDD_VERBOSE in
        info)     OPTION="${OPTION} -v"   ;;
        debug)    OPTION="${OPTION} -v -v";;
    esac


    case $WSDD_ADDRESS_FAMILY in
        IPv4only) OPTION="${OPTION} -4"   ;;
        IPv6only) OPTION="${OPTION} -6"   ;;
    esac

    cat <<-EOF> /etc/wsdd/wsdd.cfg
	# Additional arguments for wsdd can be provided here.
	# Use, e.g., "-i eth0" to restrict operations to a specific interface
	# Refer to the wsdd(8) man page for details

	WSDD_PARAMS="${OPTION} -w ${SAMBA_WORKGROUP^^} -u daemon:daemon"
EOF
}

createSystemdLink () {
    if [ "${START_WSDD}" = 'yes'  ]; then
        systemctl --quiet enable wsdd.service
    else
        systemctl --quiet disable wsdd.service
    fi
}


# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
createSystemdLink
createWsddEnvFile
createStartStopScripts
createLogrotateFile
exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
